[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/) [![GitHub license](https://img.shields.io/github/license/Naereen/StrapDown.js.svg)](https://github.com/Naereen/StrapDown.js/blob/master/LICENSE) [![boggle_test Actions Status](https://github.com/euanacampbell/boggle_solver/workflows/boggle_test/badge.svg)](https://github.com/euanacampbell/boggle_solver/actions)

# Boggle Solver

A recursive method for finding all words in a given square grid.

## Installation

No non-standard libraries needed.

## Usage
Grid can be updated within the main.py file.

```bash
>> python3 main.py
['M', 'A', 'P']
['E', 'T', 'E']
['D', 'E', 'N']

completion:
1/9
...
9/9
complete

MET
MAT
...
PATEN
TEAMED

Words found: 46
Shortest word: MET
Longest word: TEAMED
```
